dls-powerpmac-analyse
===========================

dls_powerpmacanalyse

A library and CLI for analysing/comparing/downloading Power PMAC
configurations.

Usage
-----

Help::

    dls-powerpmac-analyse -h

Launch GUI::

    dls-powerpmac-analyse -g

Contributing
------------

See `CONTRIBUTING`_

License
-------
APACHE License. (see `LICENSE`_)

